Download one or more files listed in requested_data using the authenticated
session in account_login. Files are written to path. Downloads occur in
the calling R process but the file write and optional extraction are
performed in a background R process (via callr::r_bg). If unzip = TRUE
the original archive is removed after extraction.
Arguments
- requested_data
data.frame A tibble with archive metadata that must include at minimum a
downloadcolumn (full download URL) and anidcolumn used for tracking.- account_login
list Output from
account_login()containing the authenticated session used to fetch file content.- path
character(1) Filesystem path where downloaded files will be written and (if
unzip = TRUE) extracted. The path must already exist.- unzip
logical(1) If TRUE (default) extract the downloaded .7z archive using archive::archive_extract and delete the archive file afterwards.